package com.sundata.internalevaluation.configuration.service;

import com.sundata.internalevaluation.configuration.mapper.DataSourcesMapper;
import com.sundata.internalevaluation.configuration.model.DataItemConfigModel;
import com.sundata.internalevaluation.configuration.model.DataSourcesModel;
import com.sundata.internalevaluation.configuration.model.InputParamModel;
import com.sundata.internalevaluation.configuration.model.QueryLogicModel;
import org.bouncycastle.pqc.jcajce.provider.sphincsplus.SignatureSpi;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.annotation.AccessType;
import org.springframework.stereotype.Service;

import java.util.List;

@Service
public class DataSourcesService {

    @Autowired
    DataSourcesMapper dataSourcesMapper;

    /**
     * @author: 张艳杰
     * @methodsName: getDataList
     * @description: 数据来源配置初始化
     * @param: DataSourcesModel model
     * @return: List<DataSourcesModel>
     * @throws:
     */
    public List<DataSourcesModel> getDataList(DataSourcesModel model) {
        return dataSourcesMapper.getDataList(model);
    }

    /**
     * @author: 张艳杰
     * @methodsName: createData
     * @description: 数据来源配置新增
     * @param: DataSourcesModel model
     * @return:
     * @throws:
     */
    public void createData(DataSourcesModel model) {
        dataSourcesMapper.createData(model);
        dataSourcesMapper.createInputParamData(model.getInputParam());

        for (DataItemConfigModel m : model.getDataItemConfig()) {
            m.setDataSourcesNo(model.getDataSourcesNo());
        }
        dataSourcesMapper.createDataItemConfigData(model.getDataItemConfig());
        for ( QueryLogicModel m : model.getQueryLogic()) {
            m.setDataSourcesNo(model.getDataSourcesNo());
        }
        dataSourcesMapper.createQueryLogicData(model.getQueryLogic());
    }

    /**
     * @author: 张艳杰
     * @methodsName: deleteRows
     * @description: 数据来源配置删除
     * @param: DataSourcesModel model
     * @return:
     * @throws:
     */
    public void deleteRows(DataSourcesModel model) {
        dataSourcesMapper.deleteRows(model);
    }

    /**
     * @author: 张艳杰
     * @methodsName: updateExistData
     * @description: 数据来源配置修改
     * @param: DataSourcesModel model
     * @return:
     * @throws:
     */
    public void updateExistData(DataSourcesModel model) {
        dataSourcesMapper.updateExistData(model);
        dataSourcesMapper.deleteInputParamRows();
        dataSourcesMapper.deleteDataSourceRows(model);
        dataSourcesMapper.deleteQueryLogicRows(model);
        dataSourcesMapper.createInputParamData(model.getInputParam());
        for (DataItemConfigModel m : model.getDataItemConfig()) {
            m.setDataSourcesNo(model.getDataSourcesNo());
        }
        dataSourcesMapper.createDataItemConfigData(model.getDataItemConfig());
        for ( QueryLogicModel m : model.getQueryLogic()) {
            m.setDataSourcesNo(model.getDataSourcesNo());
        }
        dataSourcesMapper.createQueryLogicData(model.getQueryLogic());
    }

    /**
     * @author: 张艳杰
     * @methodsName: selectRowData
     * @description: 数据来源配置修改
     * @param: DataSourcesModel model
     * @return:
     * @throws:
     */
    public DataSourcesModel selectDetailData(DataSourcesModel model) {
        List<InputParamModel> inputList = dataSourcesMapper.getInputParamList(model);
        List<DataItemConfigModel> dataItemList = dataSourcesMapper.getDataItemConfigList(model);
        List<QueryLogicModel> queryLogicList = dataSourcesMapper.getQueryLogicList(model);
        model.setInputParam(inputList);
        model.setQueryLogic(queryLogicList);
        model.setDataItemConfig(dataItemList);
        return model;
    }



}
